==> sunac_flutter_cli-0.1.0.tar.gz: lib/commands/impl/args_mixin.dart <==
import 'package:http/http.dart';
import 'package:recase/recase.dart';

import '../../core/generator.dart';

mixin ArgsMixin {
  final List<String> _args = GetCli.arguments;

  /// all arguments
  ///
  /// example run
  /// `get create page:product on home`
  ///
  /// ```
  /// print(args); // [page:product]
  /// ```
  List<String> args = _getArgs();

  /// all flags
  ///
  /// example run
  /// `get sort . --skipRename --relative`
  ///
  /// ```
  /// print(flags); // [--skipRename, --relative]
  /// ```
  List<String> flags = _getFlags();

  /// return parameter `on`
  ///
  /// example run
  /// `get create page:product on home`
  ///
  /// ```
  /// print(onCommand); // home
  /// ```
  String get onCommand {
    return _getArg('on');
  }

  /// return parameter `with`
  ///
  /// example run
  /// `get g model with assets/model/user.json`
  ///
  /// ```
  /// print(withArgument); //  assets/model/user.json
  /// ```
  String get withArgument {
    return _getArg('with');
  }

  /// return parameter `from`
  ///
  /// example run
  /// `get g model from 'YOUR_MODEL_URL'`
  ///
  /// ```
  /// print(fromArgument); // 'YOUR_MODEL_URL'
  /// ```
  String get fromArgument {
    return _getArg('from');
  }

  /// return parameter `name`
  ///
  /// example run
  /// `get create gx`
  /// `get create app gx`
  /// `get create module gx`
  ///
  /// ```
  /// print(name); // gx
  /// ```
  String get name {
    var args = List.of(_args);
    _removeDefaultArgs(args);
    if (args.length > 1) {
      if (args[0] == 'create') {
        var name = args[1];
        if (name == 'app' || name == 'module') {
          if (args.length > 2) {
            name = args[2];
          } else {
            name = '.';
          }
        }
        return name.isEmpty ? '.' : name.snakeCase;
      }
    }
    return '.';
  }

  /// return parameter `type`
  ///
  /// example run
  /// `get create gx`
  /// `get create app gx`
  /// `get create module gx`
  ///
  /// ```
  /// print(type); // app
  /// print(type); // app
  /// print(type); // module
  /// ```
  String get type {
    var args = List.of(_args);
    _removeDefaultArgs(args);
    if (args.length > 1) {
      if (args[0] == 'create') {
        var type = args[1];
        if (type == 'app' || type == 'module') {
          return type;
        }
      }
    }
    return 'app';
  }

  /// return [true] if contains flags
  ///
  /// example run
  /// `get sort . --skipRename`
  ///
  /// ```
  /// print(containsArg('--skipRename')); // true
  /// print(containsArg('--relative')); // false
  /// ```
  bool containsArg(String flag) {
    return _args.contains(flag);
  }
}

List<String> _getArgs() {
  var args = List.of(GetCli.arguments);
  _removeDefaultArgs(args);
  args.removeWhere((element) => element.startsWith('-'));
  return args;
}

void _removeDefaultArgs(List<String> args) {
  var defaultArgs = ['on', 'from', 'with'];

  for (var arg in defaultArgs) {
    var indexArg = args.indexWhere((element) => (element == arg));
    if (indexArg != -1 && indexArg < args.length) {
      args.removeAt(indexArg);
      if (indexArg < args.length) {
        args.removeAt(indexArg);
      }
    }
  }
}

List<String> _getFlags() {
  var args = List.of(GetCli.arguments);
  var flags = args.where((element) {
    return element.startsWith('-') && element != '--debug';
  }).toList();

  return flags;
}

int _getIndexArg(String arg) {
  return GetCli.arguments.indexWhere((element) => element == arg);
}

String _getArg(String arg) {
  var index = _getIndexArg(arg);
  if (index != -1) {
    if (index + 1 < GetCli.arguments.length) {
      index++;
      return GetCli.arguments[index];
    } else {
      throw ClientException("the '$arg' argument is empty");
    }
  }

  return '';
}

==> sunac_flutter_cli-1.0.1.tar.gz: lib/commands/impl/args_mixin.dart <==
import 'package:http/http.dart';
import 'package:recase/recase.dart';

import '../../core/generator.dart';

mixin ArgsMixin {
  final List<String> _args = SunacFlutterCli.arguments;

  /// all arguments
  ///
  /// example run
  /// `sunac create module`
  ///
  /// ```
  /// print(args); // [module]
  /// ```
  List<String> args = _getArgs();

  /// all flags
  ///
  /// example run
  /// `sunac sort . --skipRename --relative`
  ///
  /// ```
  /// print(flags); // [--skipRename, --relative]
  /// ```
  List<String> flags = _getFlags();

  /// return parameter `name`
  ///
  /// example run
  /// `sunac create gx`
  /// `sunac create app gx`
  /// `sunac create module gx`
  ///
  /// ```
  /// print(name); // gx
  /// ```
  String get name {
    var args = List.of(_args);
    _removeDefaultArgs(args);
    if (args.length > 1) {
      if (args[0] == 'create') {
        var name = args[1];
        if (name == 'app' || name == 'module') {
          if (args.length > 2) {
            name = args[2];
          } else {
            name = '.';
          }
        }
        return name.isEmpty ? '.' : name.snakeCase;
      }
    }
    return '.';
  }

  /// return parameter `type`
  ///
  /// example run
  /// `sunac create gx`
  /// `sunac create app gx`
  /// `sunac create module gx`
  ///
  /// ```
  /// print(type); // app
  /// print(type); // app
  /// print(type); // module
  /// ```
  String get type {
    var args = List.of(_args);
    _removeDefaultArgs(args);
    if (args.length > 1) {
      if (args[0] == 'create') {
        var type = args[1];
        if (type == 'app' || type == 'module') {
          return type;
        }
      }
    }
    return 'app';
  }

  /// return [true] if contains flags
  ///
  /// example run
  /// `sunac sort . --skipRename`
  ///
  /// ```
  /// print(containsArg('--skipRename')); // true
  /// print(containsArg('--relative')); // false
  /// ```
  bool containsArg(String flag) {
    return _args.contains(flag);
  }
}

List<String> _getArgs() {
  var args = List.of(SunacFlutterCli.arguments);
  _removeDefaultArgs(args);
  args.removeWhere((element) => element.startsWith('-'));
  return args;
}

void _removeDefaultArgs(List<String> args) {
  var defaultArgs = ['on', 'from', 'with'];

  for (var arg in defaultArgs) {
    var indexArg = args.indexWhere((element) => (element == arg));
    if (indexArg != -1 && indexArg < args.length) {
      args.removeAt(indexArg);
      if (indexArg < args.length) {
        args.removeAt(indexArg);
      }
    }
  }
}

List<String> _getFlags() {
  var args = List.of(SunacFlutterCli.arguments);
  var flags = args.where((element) {
    return element.startsWith('-') && element != '--debug';
  }).toList();

  return flags;
}

int _getIndexArg(String arg) {
  return SunacFlutterCli.arguments.indexWhere((element) => element == arg);
}

String _getArg(String arg) {
  var index = _getIndexArg(arg);
  if (index != -1) {
    if (index + 1 < SunacFlutterCli.arguments.length) {
      index++;
      return SunacFlutterCli.arguments[index];
    } else {
      throw ClientException("the '$arg' argument is empty");
    }
  }

  return '';
}
